@@ -39,6 +39,7 @@ from lino.core import layouts
 #~ from lino.core import changes
 from lino.core.dbutils import resolve_model
 from lino.core.requests import ActionRequest
+from lino.core.constants import _handle_attr_name
 from lino.utils import curry, AttrDict
 #~ from lino.core import perms
 from lino.utils import jsgen
@@ -526,8 +527,8 @@ class Actor(actions.Parametrizable):
     def get_request_handle(self,ar):
         # don't override
         if self.get_handle_name is None:
-            return self._get_handle(ar,ar.ui,ar.ui._handle_attr_name)
-        return self._get_handle(ar,ar.ui,self.get_handle_name(ar))
+            return self._get_handle(ar,_handle_attr_name)
+        return self._get_handle(ar,self.get_handle_name(ar))
         
     @classmethod
     def is_valid_row(self,row):
@@ -545,42 +546,43 @@ class Actor(actions.Parametrizable):
             
     @classmethod
     def has_handle(self,ui):
-        if ui is None:
-            hname = '_lino_console_handler'
-        else:
-            hname = ui._handle_attr_name
-        return self.__dict__.get(hname,False)
+        #~ if ui is None:
+            #~ hname = '_lino_console_handler'
+        #~ else:
+            #~ hname = _handle_attr_name
+        #~ return self.__dict__.get(hname,False)
+        return self.__dict__.get(_handle_attr_name,False)
         
     @classmethod
     def on_analyze(self,site):
         pass
         
     @classmethod
-    def get_handle(self,ui):
+    def summary_row(cls,ar,obj,**kw):
+        return obj.summary_row(ar,**kw)
+    
+    @classmethod
+    def get_handle(self):
         #~ assert ar is None or isinstance(ui,UI), \
             #~ "%s.get_handle() : %r is not a BaseUI" % (self,ui)
         if self.get_handle_name is not None:
             raise Exception(
                 "Tried to get static handle for %s (get_handle_name is %r)" 
                 % (self,self.get_handle_name))
-        if ui is None:
-            hname = '_lino_console_handler'
-        else:
-            hname = ui._handle_attr_name
-        return self._get_handle(None,ui,hname)
+        #~ if ui is None:
+            #~ hname = '_lino_console_handler'
+        #~ else:
+            #~ hname = _handle_attr_name
+        return self._get_handle(None,_handle_attr_name)
         
     @classmethod
-    def summary_row(cls,ar,obj,**kw):
-        return obj.summary_row(ar,**kw)
-    
-    @classmethod
-    def _get_handle(self,ar,ui,hname):
-        # attention, don't inherit from parent!
+    def _get_handle(self,ar,hname):
+        # don't inherit from parent!
         h = self.__dict__.get(hname,None)
         if h is None:
             #~ if self._replaced_by is not None:
                 #~ raise Exception("Trying to get handle for %s which is replaced by %s" % (self,self._replaced_by))
-            h = self._handle_class(ui,self)
+            h = self._handle_class(self)
             setattr(self,hname,h)
             h.setup(ar)
         return h
@@ -662,6 +664,14 @@ class Actor(actions.Parametrizable):
         if cls.label is None:
             #~ self.label = capfirst(self.model._meta.verbose_name_plural)
             cls.label = cls.get_actor_label()
+            
+        #~ if cls.parameters is not None:
+            #~ for name,f in cls.parameters.items():
+                #~ if isinstance(f,models.ForeignKey):
+                    #~ if f.verbose_name is None:
+                        #~ f.rel.to = resolve_model(f.rel.to)
+                        #~ f.verbose_name = f.rel.to._meta.verbose_name
+          
           
                 
         if False:
@@ -1162,7 +1172,7 @@ class Actor(actions.Parametrizable):
 
         
     @classmethod
-    def slave_as_html_meth(self,ui):
+    def slave_as_html_meth(self):
         """
         Creates and returns the method to be used when 
         :attr:`AbstractTable.slave_grid_format` is `html`.
@@ -1171,15 +1181,15 @@ class Actor(actions.Parametrizable):
             #~ ar = self.request(ui,request=ar.request,
                 #~ master_instance=master,param_values={})
             ar = self.request(master,request=ar.request,param_values={})
-            ar.renderer = ui.default_renderer
+            ar.renderer = settings.SITE.ui.default_renderer
             #~ s = ui.table2xhtml(ar).tostring()
-            return ui.table2xhtml(ar)
+            return settings.SITE.ui.table2xhtml(ar)
             #~ s = etree.tostring(ui.table2xhtml(ar))
             #~ return s
         return meth
         
     @classmethod
-    def to_rst(self,master_instance=None,column_names=None,**known_values):
+    def show(self,master_instance=None,column_names=None,**known_values):
         """
         Shortcut which creates an action request for this actor 
         and calls its :meth:`lino.core.actions.ActionRequest.to_rst` 
@@ -1191,7 +1201,7 @@ class Actor(actions.Parametrizable):
         kw.update(actor=self)
         kw.update(known_values=known_values)
         kw.update(renderer=settings.SITE.ui.text_renderer)
-        return self.request(**kw).to_rst(column_names)
+        print self.request(**kw).to_rst(column_names)
         #~ return settings.SITE.ui.text_renderer.request(**kw).to_rst(column_names)
         #~ username = kw.pop('username',None)
         #~ if username and settings.SITE.user_model is not None:
@@ -1202,12 +1212,11 @@ class Actor(actions.Parametrizable):
     @classmethod
     def to_html(self,**kw):
         """
-        Shortcut which calls :meth:`lino.Lino.startup`, 
-        creates an action request for this actor 
-        and calls its :meth:`ActionRequest.table2xhtml` method.
         """
-        settings.SITE.startup()
+        #~ settings.SITE.startup()
         return xghtml.E.tostring(self.request(**kw).table2xhtml())
+        #~ return self.request(**kw).table2xhtml()
         
-    def show(self,*args,**kw):
-        print self.to_rst(*args,**kw)
+    #~ def show(self,*args,**kw):
+        #~ print self.to_rst(*args,**kw)
+
