@@ -170,9 +170,21 @@ def startup_site(self):
         for f in model._meta.virtual_fields:
             if isinstance(f,generic.GenericForeignKey):
                 settings.SITE.GFK_LIST.append(f)
+
+    for a in models.get_apps():
+        #~ for app_label,a in loading.cache.app_store.items():
+        app_label = a.__name__.split('.')[-2]
+        #~ logger.info("Installing %s = %s" ,app_label,a)
+        
+        for k,v in a.__dict__.items():
+            if isinstance(v,type) and issubclass(v,layouts.BaseLayout):
+                #~ print "%s.%s = %r" % (app_label,k,v)
+                self.modules.define(app_label,k,v)
+            #~ if isinstance(v,type)  and issubclass(v,dd.Module):
+                #~ logger.info("20120128 Found module %s",v)
+            if k.startswith('setup_'):
+                self.modules.define(app_label,k,v)
                 
-    dd.pre_analyze.send(self,models_list=models_list)
-    
     self.setup_choicelists()
     self.setup_workflows()
     
@@ -202,6 +214,10 @@ def startup_site(self):
                     #~ f.rel.to._lino_ddh.add_fk(model,f) # 20120728
                     f.rel.to._lino_ddh.add_fk(m or model,f)
                         
+    dd.pre_analyze.send(self,models_list=models_list)
+    # MergeAction are defined in pre_analyze. 
+    # And MergeAction needs the info in _lino_ddh to correctly find keep_volatiles
+    
     #~ for model in models.get_models():
 
             #~ for k,v in class_dict_items(model):
@@ -210,20 +226,6 @@ def startup_site(self):
                     
                     
     
-    for a in models.get_apps():
-        #~ for app_label,a in loading.cache.app_store.items():
-        app_label = a.__name__.split('.')[-2]
-        #~ logger.info("Installing %s = %s" ,app_label,a)
-        
-        for k,v in a.__dict__.items():
-            if isinstance(v,type) and issubclass(v,layouts.BaseLayout):
-                #~ print "%s.%s = %r" % (app_label,k,v)
-                self.modules.define(app_label,k,v)
-            #~ if isinstance(v,type)  and issubclass(v,dd.Module):
-                #~ logger.info("20120128 Found module %s",v)
-            if k.startswith('setup_'):
-                self.modules.define(app_label,k,v)
-                    
     for model in models_list:
       
         """
@@ -241,9 +243,7 @@ def startup_site(self):
                     
                     
     actors.discover()
-    
     dbtables.discover()
-    
     choosers.discover()
                     
     #~ from lino.core import ui
@@ -281,6 +281,9 @@ def startup_site(self):
 
     self.resolve_virtual_fields()
     
+    from lino.ui.ui import ExtUI
+    self.ui = ExtUI(self)
+    
 class DisableDeleteHandler():
     """
     Used to find out whether a known object can be deleted or not.
