@@ -12,6 +12,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import unicode_literals
+
 import logging
 logger = logging.getLogger(__name__)
 
@@ -21,6 +23,7 @@ from django.db import models
 from django.conf import settings
 from django.utils.translation import ugettext as _
 
+
 from django.core.exceptions import ValidationError
 #~ from django.core.exceptions import MultipleObjectsReturned
 
@@ -28,7 +31,7 @@ from django.core.exceptions import ValidationError
 from lino.core import fields
 from lino.core import signals
 from lino.core import dbutils
-from djangosite.dbutils import obj2str
+from djangosite.dbutils import obj2str, full_model_name
 from lino.utils.xmlgen import html as xghtml
 E = xghtml.E
 
@@ -199,6 +202,19 @@ class Model(models.Model):
         """
         pass
         
+    @classmethod
+    def define_action(cls,**kw):
+        """
+        Adds one or several actions to this model.
+        Actions must be specified using keyword arguments.
+        
+        """
+        for k,v in kw.items():
+            if hasattr(cls,k):
+                raise Exception("Tried to redefine %s.%s" % (cls,k))
+            setattr(cls,k,v)
+        
+        
     @classmethod
     def hide_elements(self,*names):
         """
@@ -445,6 +461,7 @@ class Model(models.Model):
             #~ yield ( 'merge_row', MergeAction(self) )
             
     def to_html(self,**kw):
+        import lino.ui.urls # hack: trigger ui instantiation
         actor=self.get_default_table()
         kw.update(renderer=settings.SITE.ui.text_renderer)
         #~ ar = settings.SITE.ui.text_renderer.request(**kw)
@@ -481,7 +498,38 @@ class Model(models.Model):
               'disable_delete',
               'lookup_or_create',
               'on_duplicate',
-              'on_create')
+              'on_create',
+              'print_subclasses_graph')
     """
     Used by :mod:`lino.core.kernel`
     """
+    
+
+    @classmethod
+    def print_subclasses_graph(self):
+        """
+        Returns a `graphviz` directive 
+        Used in welfare.userdocs to generate a internationalized graphviz::
+        
+          \.. py2rst:: print contacts.Partner.model_graphviz()
+          
+        """
+        from lino import dd
+        pairs = []
+        def collect(m):
+            for b in dd.models_by_base(m):
+              if b is not m and (m in b.__bases__):
+                pairs.append((m._meta.verbose_name,b._meta.verbose_name))
+                collect(b)
+        collect(self)
+        s = '\n'.join(['    "%s" -> "%s"' % x for x in pairs])
+        s = """
+
+.. graphviz:: 
+   
+   digraph foo {
+%s   
+  }
+  
+""" % s
+        print s
