@@ -20,6 +20,7 @@ logger = logging.getLogger(__name__)
 import traceback
 #~ from django.utils.translation import ugettext as _
 from django.utils.translation import ugettext_lazy as _
+from north.dbutils import set_language
 from django.utils.encoding import force_unicode
 from django.conf import settings
 from django import http
@@ -140,13 +141,18 @@ class BaseRequest(object):
         
     def setup_from(self,other):
         """
+        Copy certain values 
+        (render, user, subst_user & requesting_panel) 
+        from this request to the other.
+        
         """
-        if not other.must_execute():
-            raise Exception("Request %r was already executed" % other)
+        if not self.must_execute():
+            return
+            #~ raise Exception("Request %r was already executed" % other)
         self.renderer = other.renderer
         self.user = other.user
         self.subst_user = other.subst_user
-        #~ self.requesting_panel = other.requesting_panel
+        self.requesting_panel = other.requesting_panel
   
     def parse_req(self,request,rqdata,**kw): 
         #~ if self.actor.parameters:
@@ -256,8 +262,32 @@ class BaseRequest(object):
             from_email=sender,body=body,to=recipients)
         msg.send()
         logger.info("System note '%s' from %s has been sent to %s",subject,sender,recipients)
+        
+    def spawn(self,spec,**kw):
+        """
+        Create a new ActionRequest, taking an "action specificator" 
+        and using default values from this one (via :meth:setup_from`).
+        """
+        if isinstance(spec,ActionRequest):
+            for k,v in kw.items():
+                assert hasattr(spec,k)
+                setattr(spec,k,v)
+            #~ if kw:
+                #~ ar = ar.spawn(**kw)
+                #~ raise Exception(20130327)
+        else:
+            from lino.core.menus import create_item
+            mi = create_item(spec)
+            spec = mi.bound_action.request(**kw)
+        spec.setup_from(self)
+        #~ ar.user = self.user
+        #~ ar.subst_user = self.subst_user
+        #~ ar.renderer = self.renderer
+        return spec
+        
+        
 
-    def spawn(self,actor,**kw):
+    def old_spawn(self,actor,*args,**kw):
         """
         Create a new ActionRequest, taking default values from this one.
         """
@@ -269,7 +299,7 @@ class BaseRequest(object):
         # removed 20120702 because i don't want to inherit quick_search from spawning request
         # and because i couldn't remember why 'request' was passed to the spawned request.
         #~ return self.ui.request(actor,**kw)
-        return actor.request(**kw)
+        return actor.request(*args,**kw)
         
     #~ def show(self,*args,**kw):
         #~ print self.to_rst(*args,**kw)
@@ -277,22 +307,12 @@ class BaseRequest(object):
     def run(self,ia,*args,**kw):
         return ia.run_from_session(self,*args,**kw)
         
-    def show(self,ar,column_names=None,**kw):
-        if isinstance(ar,ActionRequest):
-            for k,v in kw.items():
-                assert hasattr(ar,k)
-                setattr(ar,k,v)
-            #~ if kw:
-                #~ ar = ar.spawn(**kw)
-                #~ raise Exception(20130327)
-        else:
-            from lino.core.menus import create_item
-            mi = create_item(ar)
-            ar = mi.bound_action.request(**kw)
-        ar.setup_from(self)
-        #~ ar.user = self.user
-        #~ ar.subst_user = self.subst_user
-        #~ ar.renderer = self.renderer
+    def set_language(self,*args):
+        set_language(*args)
+        
+        
+    def show(self,spec,column_names=None,**kw):
+        ar = self.spawn(spec,**kw)
         print ar.to_rst(column_names)
         
             
@@ -494,7 +514,7 @@ class ActionRequest(BaseRequest):
         return kw
         
 
-    def spawn(self,actor=None,**kw):
+    def spawn(self,actor,**kw):
         if actor is None:
             actor = self.actor
         return super(ActionRequest,self).spawn(actor,**kw)
@@ -518,12 +538,10 @@ class ActionRequest(BaseRequest):
         location = ar.get_request_url()
         return self.request.build_absolute_uri(location)
         
-            
-    def to_rst(self,column_names=None):
+        
+    def to_rst(self,*args,**kw):
         """
         Returns a string representing this request in reStructuredText markup.
         """
-        raise NotImplementedError()
-            
-        
-        
+        return self.actor.to_rst(self,*args,**kw)
+        #~ raise NotImplementedError()
