@@ -952,7 +952,7 @@ tinymce.init({
         
         actions_written = set()
         for rpt in actors_list:
-            rh = rpt.get_handle(settings.SITE.ui) 
+            rh = rpt.get_handle() 
             for ba in rpt.get_actions():
                 if ba.action.parameters:
                     if not ba.action in actions_written:
@@ -962,7 +962,7 @@ tinymce.init({
                             f.write(ln + '\n')
           
         for rpt in actors_list:
-            rh = rpt.get_handle(settings.SITE.ui) 
+            rh = rpt.get_handle() 
             if isinstance(rpt,type) and issubclass(rpt,(tables.AbstractTable,choicelists.ChoiceList)):
                 #~ if rpt.model is None:
                 #~ f.write('// 20120621 %s\n' % rpt)
@@ -1517,6 +1517,7 @@ tinymce.init({
         """
         Called from :xfile:`linolib.js`.
         """
+        
         def fn():
             yield """// lino.js --- generated %s by Lino version %s.""" % (time.ctime(),lino.__version__)
             #~ // $site.title ($lino.welcome_text())
@@ -1525,7 +1526,7 @@ tinymce.init({
             # TODO: replace the following lines by a generic method for all ChoiceLists
             #~ yield "STRENGTH_CHOICES = %s;" % py2js(list(STRENGTH_CHOICES))
             #~ yield "KNOWLEDGE_CHOICES = %s;" % py2js(list(KNOWLEDGE_CHOICES))
-            yield "MEDIA_URL = %r;" % settings.SITE.build_media_url()
+            yield "MEDIA_URL = %s;" % py2js(settings.SITE.build_media_url())
             #~ yield "ADMIN_URL = %r;" % settings.SITE.admin_prefix
             
             #~ yield "API_URL = %r;" % self.build_url('api')
