@@ -26,7 +26,7 @@ from django.conf import settings
 from django.db import models
 from django.db.models import Q
 from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import pgettext_lazy
+from django.utils.translation import pgettext_lazy as pgettext
 #~ from django.utils.translation import string_concat
 from django.contrib.contenttypes.models import ContentType
 from django.utils.encoding import force_unicode
@@ -93,7 +93,7 @@ add = TaskStates.add_item
 
 #~ add('00', _("Virgin"),'todo')
 add('10', _("To do"),'todo')
-add('20', pgettext_lazy(u"cal",u"Started"),'started')
+add('20', pgettext(u"cal",u"Started"),'started')
 add('30', _("Done"),'done')
 #~ add('40', _("Sleeping"),'sleeping')
 add('50', _("Cancelled"),'cancelled')
@@ -137,24 +137,7 @@ class RejectInvitation(dd.ChangeStateAction,dd.NotifyingAction):
 
 #~ class EventStates(ChoiceList):
 class EventStates(dd.Workflow):
-    """
-    Workflow state of a Calendar Event. 
-    """
-    #~ label = _("State")
-    
-    #~ @classmethod
-    #~ def allow_state_suggest(cls,self,user):
-        #~ if not self.start_time: return False
-        #~ return True
-        
-    #~ @classmethod
-    #~ def before_state_change(cls,obj,ar,kw,oldstate,newstate):
-      
-        #~ if newstate.name == 'draft':
-            #~ ar.confirm(_("This will reset all invitations"))
-            #~ for g in obj.guest_set.all():
-                #~ g.state = GuestStates.invited
-                #~ g.save()
+    help_text = _("""List of the possible states of a calendar event.""")
         
         
         
@@ -381,6 +364,9 @@ class Calendar(mixins.PrintableType,outbox.MailableType,dd.BabelNamed):
         
     
 class Calendars(dd.Table):
+    help_text = _("""The list of calendars defined on this system.
+    A calendar is a list of events which have certain things in common,
+    especially they are displayed in the same colour in the calendar panel""")
     required = dd.required(user_groups='office',user_level='manager')
     model = 'cal.Calendar'
     column_names = "name type color readonly build_method template *"
@@ -520,6 +506,7 @@ class Place(dd.BabelNamed):
         
   
 class Places(dd.Table):
+    help_text = _("List of places where calendar events can happen.")
     required = dd.required(user_groups='office')
     model = Place
     detail_layout = """
@@ -535,6 +522,7 @@ class Priority(dd.BabelNamed):
     ref = models.CharField(max_length='1')
 
 class Priorities(dd.Table):
+    help_text = _("List of possible priorities of calendar events.")
     required = dd.required(user_groups='office')
     model = Priority
     column_names = 'name *'
@@ -548,8 +536,8 @@ class Priorities(dd.Table):
     #~ templates_group = 'cal/Event'
     
     #~ class Meta:
-        #~ verbose_name = pgettext_lazy(u"cal",u"Event Type")
-        #~ verbose_name_plural = pgettext_lazy(u"cal",u'Event Types')
+        #~ verbose_name = pgettext(u"cal",u"Event Type")
+        #~ verbose_name_plural = pgettext(u"cal",u'Event Types')
 
 #~ class EventTypes(dd.Table):
     #~ model = EventType
@@ -1085,8 +1073,8 @@ class Event(Component,Ended,
     
     class Meta:
         #~ abstract = True
-        verbose_name = pgettext_lazy(u"cal",u"Event")
-        verbose_name_plural = pgettext_lazy(u"cal",u"Events")
+        verbose_name = pgettext(u"cal",u"Event")
+        verbose_name_plural = pgettext(u"cal",u"Events")
         
     transparent = models.BooleanField(_("Transparent"),default=False,help_text=_("""\
 Indicates that this Event shouldn't prevent other Events at the same time."""))
@@ -1280,6 +1268,7 @@ class EventInsert(EventDetail):
 unclear_event_states = (EventStates.suggested,EventStates.draft,EventStates.notified)
 
 class Events(dd.Table):
+    help_text = _("A List of calendar entries. Each entry is called an event.")
     #~ debug_permissions = True
     model = 'cal.Event'
     required = dd.required(user_groups='office',user_level='manager')
@@ -1427,19 +1416,6 @@ if settings.SITE.user_model:
             kw.update(user=ar.get_user())
             return kw
         
-    #~ class EventsReserved(Events):
-        #~ help_text = _("Table of all reserved events.")
-        #~ label = _("Reserved Events")
-        #~ required = dict(user_groups='office',user_level='manager')
-        #~ column_names = 'start_date start_time user project summary workflow_buttons *'
-        #~ known_values = dict(state=EventStates.reserved)
-        
-    #~ class MyEventsReserved(EventsReserved,MyEvents):
-        #~ help_text = _("Table of my reserved events (to become scheduled).")
-        #~ required = dict(user_groups='office')
-        #~ column_names = 'start_date start_time project summary workflow_buttons *'
-        #~ label = _("My reserved Events")
-        
         
     class MyUnclearEvents(MyEvents):
         label = _("My unclear events")
@@ -1662,6 +1638,8 @@ class Task(Component):
         
 
 class Tasks(dd.Table):
+    help_text = _("""A calendar task is something you need to do.
+    """)
     #~ debug_permissions = True
     model = 'cal.Task'
     required = dd.required(user_groups='office')
@@ -1730,10 +1708,6 @@ if settings.SITE.project_model:
     
 
 class GuestRole(mixins.PrintableType,outbox.MailableType,dd.BabelNamed):
-    """
-    A possible value for the `role` field of an :class:`Guest`.
-    """
-    
     templates_group = 'cal/Guest'
     
     class Meta:
@@ -1742,9 +1716,8 @@ class GuestRole(mixins.PrintableType,outbox.MailableType,dd.BabelNamed):
 
 
 class GuestRoles(dd.Table):
-    """
-    Table showing all :class:`GuestRole` objects.
-    """
+    help_text = _("""The role of a guest expresses what the 
+    partner is going to do there.""")
     model = GuestRole
     required = dd.required(user_groups='office')
     detail_layout = """
@@ -1755,9 +1728,6 @@ class GuestRoles(dd.Table):
     
 
 class Guest(mixins.TypedPrintable,outbox.Mailable):
-    """
-    A Guest is a Partner who is invited to an :class:`Event`.
-    """
     
     workflow_state_field = 'state'
     
@@ -1844,6 +1814,8 @@ class Guest(mixins.TypedPrintable,outbox.Mailable):
     
 #~ class Guests(dd.Table,workflows.Workflowable):
 class Guests(dd.Table):
+    help_text = _("""A guest is a partner invited to an event.
+    """)
     model = Guest
     required = dd.required(user_groups='office')
     column_names = 'partner role workflow_buttons remark event *'
@@ -2322,9 +2294,12 @@ def reminders_as_html(ar,days_back=None,days_forward=None,**kw):
     #~ filterkw.update(user=user)
     
     events = ar.spawn(MyEvents,
-        master_instance=user,
+        #~ master_instance=user,
+        user=user,
         filter=flt & (models.Q(state=None) | models.Q(state__lte=EventStates.scheduled)))
-    tasks = ar.spawn(MyTasks,master_instance=user,
+    tasks = ar.spawn(MyTasks,
+        #~ master_instance=user,
+        user=user,
         #~ filter=flt & models.Q(state__in=[TaskState.blank_item,TaskState.todo])) 20120829
         filter=flt & models.Q(state__in=[None,TaskStates.todo]))
     
@@ -2409,7 +2384,9 @@ class UpdateReminders(actions.RowAction):
 from lino.ui import models as ui
 
 class Home(ui.Home):
-  
+    """
+    Deserves better documentation.
+    """
     #~ debug_permissions = True 
 
     label = ui.Home.label
@@ -2638,7 +2615,7 @@ def setup_workflows(site):
     EventStates.rescheduled.add_workflow(_("Reschedule"),
         owner=True,
         states='scheduled notified',icon_file='date_edit.png')
-    EventStates.cancelled.add_workflow(pgettext_lazy(u"calendar event action",u"Cancel"),
+    EventStates.cancelled.add_workflow(pgettext(u"calendar event action",u"Cancel"),
         owner=True,
         states='scheduled notified',
         icon_file='cross.png')
