@@ -16,7 +16,7 @@
 from django.utils.translation import ugettext as _
 
 from lino.utils.instantiator import Instantiator
-from north.babel import babel_values
+from north.dbutils import babel_values
 
 def objects():
     ptype = Instantiator('properties.PropType').build
