@@ -45,12 +45,6 @@ from django.utils.encoding import force_unicode
 
 
 from lino import dd
-from north import dbutils
-#~ from lino.utils.dbutils import babelattr
-#~ from lino.utils import printable
-from lino import mixins
-#~ from lino import fields
-from lino.utils.choosers import chooser
 
 from lino.core.choicelists import get_choicelist, choicelist_choices
 
@@ -133,7 +127,7 @@ class PropType(dd.BabelNamed):
     not yet supported
     """
     
-    @chooser()
+    @dd.chooser()
     def default_value_choices(cls,choicelist):
         if choicelist:
             return get_choicelist(choicelist).get_choices()
@@ -152,14 +146,14 @@ class PropType(dd.BabelNamed):
         for v in value.split(MULTIPLE_VALUES_SEP):
             try:
                 pc = PropChoice.objects.get(value=v,type=self)
-                v = dbutils.babelattr(pc,'text')
+                v = dd.babelattr(pc,'text')
             except PropChoice.DoesNotExist:
                 pass
             l.append(v)
         return ','.join(l)
         
     #~ def __unicode__(self):
-        #~ return dbutils.babelattr(self,'name')
+        #~ return dd.babelattr(self,'name')
         
     def choices_for(self,property):
         if self.choicelist:
@@ -192,7 +186,7 @@ class PropChoice(dd.Model):
         
     type = models.ForeignKey(PropType,verbose_name=_("Property Type"))
     value = models.CharField(max_length=settings.SITE.propvalue_max_length,verbose_name=_("Value"))
-    text = dbutils.BabelCharField(max_length=200,verbose_name=_("Designation"),blank=True)
+    text = dd.BabelCharField(max_length=200,verbose_name=_("Designation"),blank=True)
     
     def save(self,*args,**kw):
         if not self.text:
@@ -201,9 +195,9 @@ class PropChoice(dd.Model):
         return r
         
     def __unicode__(self):
-        return dbutils.babelattr(self,'text')
+        return dd.babelattr(self,'text')
 
-class PropGroup(dbutils.BabelNamed):
+class PropGroup(dd.BabelNamed):
     """
     A Property Group defines a list of Properties that fit together under a common name.
     Examples of Property Groups: Skills, Soft Skills, Obstacles
@@ -212,20 +206,25 @@ class PropGroup(dbutils.BabelNamed):
     class Meta:
         verbose_name = _("Property Group")
         verbose_name_plural = _("Property Groups")
-        
+
+#~ from django.db.models.signals import pre_delete
+#~ from django.dispatch import receiver
+#~ @receiver(pre_delete, sender=PropGroup)
+#~ def my_handler(sender, instance=None, **kwargs):
+    #~ print "Gonna delete", dd.obj2str(instance,True)
 
 
-class Property(dbutils.BabelNamed):
+class Property(dd.BabelNamed):
     class Meta:
         verbose_name = _("Property")
         verbose_name_plural = _("Properties")
         
-    #~ name = dbutils.BabelCharField(max_length=200,verbose_name=_("Designation"))
+    #~ name = dd.BabelCharField(max_length=200,verbose_name=_("Designation"))
     group = models.ForeignKey(PropGroup,verbose_name=_("Property Group"))
     type = models.ForeignKey(PropType,verbose_name=_("Property Type"))
     
     #~ def __unicode__(self):
-        #~ return dbutils.babelattr(self,'name')
+        #~ return dd.babelattr(self,'name')
 #~ add_babel_field(Property,'name')
 
 
@@ -255,15 +254,15 @@ class PropertyOccurence(dd.Model):
     
     #~ def get_text(self):
         #~ c = PropChoice.objects.get(type=self.property.type,value=self.value)
-        #~ return dbutils.babelattr(c,'name')
+        #~ return dd.babelattr(c,'name')
     
-    @chooser()
+    @dd.chooser()
     def value_choices(cls,property):
         if property is None:
             return []
         return property.type.choices_for(property)
             
-    @chooser()
+    @dd.chooser()
     def property_choices(cls,group):
         #~ print 20120212, group
         if group is None:
