@@ -1,6 +1,6 @@
 SETUP_INFO = dict(name = 'lino',
-  version = '1.6.4',
-  install_requires = ['North==0.1.1','appy','PyYAML','odfpy','jinja2'],
+  version = '1.6.5',
+  install_requires = ['North==0.1.2','PyYAML','odfpy','jinja2','appy'],
   description = "A framework for writing desktop-like web applications using Django and ExtJS",
   license = 'GPL',
   include_package_data = True,
@@ -9,6 +9,7 @@ SETUP_INFO = dict(name = 'lino',
   author_email = 'luc.saffre@gmail.com',
   url = "http://www.lino-framework.org",
   #~ test_suite = 'lino.test_apps',
+  test_suite = 'tests',
   classifiers="""\
   Programming Language :: Python
   Programming Language :: Python :: 2
@@ -28,32 +29,29 @@ SETUP_INFO = dict(name = 'lino',
   Topic :: Software Development :: Libraries :: Application Frameworks""".splitlines())
 
 SETUP_INFO.update(long_description = """\
-Lino is a high-level framework for writing desktop-like web applications
-based on `Django <https://www.djangoproject.com/>`_
+Lino is a high-level framework for writing desktop-like customized 
+database applications based on `Django <https://www.djangoproject.com/>`_
 and `Sencha ExtJS <http://www.sencha.com/products/extjs/>`_.
-
-Lino is for IT professionals who want to develop customized database 
-applications for their customers without writing any HTML or CSS.
-
-Lino consists of different parts:
-
-- `django-site <http://site.lino-framework.org>`__
-  (split off from main project in March 2013)
-  provides startup signals and the `settings.SITE` object.
-  
-- `django-north <https://code.google.com/p/django-north/>`__
-  (split off from main project in March 2013)
-  provides python dumps, multilingual database content and data migration.
-
-- A collection of reusable Django apps and out-of-the-box demo applications
-
-- A collection of *user interface renderers*.
-  Currently there's one for ExtJS 
-  and another for Twitter/Bootstrap-based "plain" interface.
+A Lino application is technically just a Django project, 
+but the application developer does not need to write any 
+URLconf, HTML nor CSS (`more <http://lino-framework.org/about>`_)
 
 The following real-world applications use the Lino framework:
 
 - `Lino-Welfare <http://welfare.lino-framework.org>`__
+
+Lino uses the following projects by the same author:
+
+- `atelier <http://atelier.lino-framework.org>`__
+  provides some general Python tools.
+  
+- `djangosite <http://site.lino-framework.org>`__
+  provides startup signals and the `settings.SITE` object.
+  
+- `north <http://north.lino-framework.org>`__
+  provides python dumps, multilingual database content 
+  and data migration.
+
   
 """)
 
@@ -154,6 +152,7 @@ lino.projects.cms
 lino.projects.cms.fixtures
 lino.projects.cosi
 lino.projects.cosi.fixtures
+lino.projects.cosi.tests
 lino.projects.crl
 lino.projects.crl.fixtures
 lino.projects.events
@@ -186,3 +185,18 @@ SETUP_INFO.update(message_extractors = {
         #~ })
     ],
 })
+
+SETUP_INFO.update(package_data=dict())
+def add_package_data(package,*patterns):
+    l = SETUP_INFO['package_data'].setdefault(package,[])
+    l.extend(patterns)
+    return l
+
+add_package_data('lino','config/*.odt')
+add_package_data('lino.modlib.cal','config/*.odt')
+add_package_data('lino.modlib.notes','config/notes/Note/*.odt')
+add_package_data('lino.modlib.outbox','config/outbox/Mail/*.odt')
+
+l = add_package_data('lino')
+for lng in 'de fr et nl'.split():
+    l.append('locale/%s/LC_MESSAGES/*.mo' % lng)
