@@ -544,7 +544,8 @@ class ConstantElement(LayoutElement):
     vflex = True
     
     def __init__(self,lh,fld,**kw):
-        kw.update(html=fld.text_fn(lh.layout._datasource,lh.ui))
+        #~ kw.update(html=fld.text_fn(lh.layout._datasource,lh.ui))
+        kw.update(html=fld.text_fn(lh.layout._datasource))
         #~ kw.update(html=fld.text)
         #~ kw.update(autoHeight=True)
         LayoutElement.__init__(self,lh,fld.name,**kw)
@@ -1387,12 +1388,16 @@ class BooleanFieldElement(BooleanMixin,FieldElement):
 
 
 class SingleRelatedObjectElement(DisplayElement):
+    """
+    The widget used to render a `SingleRelatedObjectDescriptor`,
+    i.e. the other side of a `OneToOneField`.
+    """
     def __init__(self,lh,relobj,**kw):
         """
         :lh: the LayoutHandle
         :relobj: the RelatedObject instance
         """
-        print(20130202, relobj.parent_model, relobj.model, relobj.field)
+        #~ print(20130202, relobj.parent_model, relobj.model, relobj.field)
         self.relobj = relobj
         self.editable = False
         kw.update(
@@ -1994,7 +1999,7 @@ class GridElement(Container):
         self.value_template = "new Lino.%s.GridPanel(%%s)" % rpt
         self.actor = rpt
         if len(columns) == 0:
-            self.rh = rpt.get_handle(layout_handle.ui)
+            self.rh = rpt.get_handle()
             if not hasattr(self.rh,'list_layout'):
                 raise Exception("%s has no list_layout" % self.rh)
             columns = self.rh.list_layout.main.columns
