@@ -13,14 +13,32 @@
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
 """
-An extended `appy.pod` renderer that installs additional functions:
+An extended :term:`appy.pod` renderer that installs additional functions
+to be used in `do text|section|table... from ...
+<http://appyframework.org/podWritingAdvancedTemplates.html>`__ 
+statements.
 
-- :meth:`restify <Renderer.restify_func>`: 
-  Render a string that is in reStructuredText markup.
-- :meth:`html <Renderer.html_func>` :
+
+- `restify(s)`: 
+  Render a string `s` which contains reStructuredText markup.
+  The string is first passed to 
+  :func:`lino.utils.restify.restify` to convert it to XHTML, 
+  then to `appy.pod`'s built in `xhtml` function.
+  Without this, users would have to write each time something like::
+
+    do text
+    from xhtml(restify(self.body).encode('utf-8'))
+
+- `html(s)` :
   Render a string that is in HTML (not XHTML).
-- :meth:`table <Renderer.insert_table>`
-  Render a Lino Action Request as a table.
+
+- `ehtml(e)` :
+  Render an ElementTree HTML object 
+  (generated using :mod:`lino.utils.xmlgen.html`)
+  by passing it to :mod:`lino.utils.html2odf`.
+
+- `table(ar,column_names=None)` : render an :class:`lino.core.tables.TableRequest` 
+  as a table.
 
 """
 
@@ -33,10 +51,6 @@ import os
 
 from appy.pod.renderer import Renderer as AppyRenderer
 
-from lino.utils.restify import restify
-from lino.utils.html2xhtml import html2xhtml
-
-
 from django.utils.encoding import force_unicode
 from django.conf import settings
 
@@ -49,6 +63,11 @@ from odf.style import TableColumnProperties, TableRowProperties, TableCellProper
 from odf import text
 from odf.table import Table, TableColumns, TableColumn, TableHeaderRows, TableRows, TableRow, TableCell
 
+from lino.utils.restify import restify
+from lino.utils.html2xhtml import html2xhtml
+from lino.utils.html2odf import html2odf, toxml
+
+
 OAS = '<office:automatic-styles>'
 OFFICE_STYLES = '<office:styles>'
 UL_LIST_STYLE = """\
@@ -67,7 +86,6 @@ UL_LIST_STYLE = """\
 </text:list-style>
 """
 
-from lino.utils.html2odf import html2odf, toxml
 
 class Renderer(AppyRenderer):
   
@@ -77,6 +95,8 @@ class Renderer(AppyRenderer):
         context.update(restify=self.restify_func)
         context.update(html=self.html_func)
         context.update(table=self.insert_table)
+        #~ context.update(html2odf=html2odf)
+        context.update(ehtml=html2odf)
         #~ from lino.extjs import ui
         #~ self.extjs_ui = ui
         #~ self.extjs_ui = settings.SITE.ui
@@ -93,19 +113,6 @@ class Renderer(AppyRenderer):
   
     def restify_func(self,unicode_string,**kw):
         """
-        Renders a string in reStructuredText markup by passing it to 
-        :func:`lino.utils.restify.restify` to convert it to XHTML, 
-        then through :term:`appy.pod`'s built in `xhtml` function.
-        
-        Without this, users would have to write each time something 
-        like::
-
-          do text
-          from xhtml(restify(self.body).encode('utf-8'))
-            
-          do text
-          from xhtml(restify(self.body,output_encoding='utf-8'))
-
         
         """
         if not unicode_string:
@@ -189,37 +196,51 @@ class Renderer(AppyRenderer):
       
         
     def insert_table(self,*args,**kw):
-        try:
+        #~ since i cannot yet tell appy_pod to alert me when there is an 
+        #~ exception, here at least i write it to the logger
+        if False:
             return self.insert_table_(*args,**kw)
-        except Exception as e:
-            logger.exception(e)
-            return ''
+        else:
+            try:
+                return self.insert_table_(*args,**kw)
+            except Exception as e:
+                logger.warning("Exception during insert_table(%s)" % args[0])
+                raise
+                logger.exception(e)
+                return ''
         
-    def insert_table_(self,ar,column_names=None):
+    def insert_table_(self,ar,column_names=None,table_width=180):
         """
-        Render an :class:`lino.core.actions.ActionRequest` as an OpenDocument table.
         This is the function that gets called when a template contains a 
         ``do text from table(...)`` statement.
         """
         ar.setup_from(self.ar)
+        #~ ar.renderer = self.ar.renderer
 
         #~ ar  = self.ar
         
         columns, headers, widths = ar.get_field_info(column_names)
-        
+        widths = map(int,widths)
         tw = sum(widths)
         """
         specifying relative widths doesn't seem to work
-        (and that's a pity because absolute widths requires a 
-        hard-coded table width). 
+        (and that's a pity because absolute widths requires us 
+        to know the table_width). 
         """
         use_relative_widths = False
         if use_relative_widths:
             width_specs = ["%d*" % (w*100/tw) for w in widths]
             #~ width_specs = [(w*100/tw) for w in widths]
         else:
-            aw = 180 # suppose table width = 18cm = 180mm
-            width_specs = ["%dmm" % (aw*w/tw) for w in widths]
+            #~ total_width = 180 # suppose table width = 18cm = 180mm
+            width_specs = ["%dmm" % (table_width*w/tw) for w in widths]
+        #~ else:
+            #~ width_specs = []
+            #~ for w in widths:
+				#~ if w.endswith('%'):
+					#~ mm = float(w[:-1]) * table_width / 100
+					#~ width_specs.append("%dmm" % mm)
+				#~ else:
         #~ print 20120419, width_specs 
         
         doc = OpenDocumentText()
@@ -320,8 +341,6 @@ class Renderer(AppyRenderer):
             #~ self.my_automaticstyles.append(cs)
             table_columns.addElement(TableColumn(stylename=name))
             
-        #~ from lino.ui.extjs3 import ext_store
-        #~ from lino.ui.extjs3 import ext_elems
         from lino.ui import elems
         def fldstyle(fld):
             #~ if isinstance(fld,ext_store.VirtStoreField):
