@@ -202,7 +202,8 @@ class UserProfile(Choice):
         if self.name:
             s += "." + self.name
         s += ":" + self.value + "("
-        s += "level=%s" % self.level.name
+        #~ s += "level=%s" % self.level.name
+        s += "level=%s" % self.level
         for g in UserGroups.items():
             if g.value: # no level for UserGroups.blank_item
                 v = getattr(self,g.value+'_level',None)
@@ -669,18 +670,18 @@ class RemoteUserMiddleware(object):
             settings.SITE.remote_user_header,settings.SITE.default_user)
             
         if not username:
-            raise exceptions.PermissionDenied(
-                "Using remote authentication, but no user credentials found.")
-            #~ raise Exception("Using remote authentication, but no user credentials found.")
+            #~ msg = "Using remote authentication, but no user credentials found."
+            #~ raise exceptions.PermissionDenied(msg)
+            raise Exception("Using remote authentication, but no user credentials found.")
             
         user = authenticate(username)
         
         if user is None:
             #~ logger.exception("Unknown username %s from request %s",username, request)
             #~ raise Exception(
-            raise exceptions.PermissionDenied(
-              "Unknown or inactive username %r. Please contact your system administrator." 
-              % username)
+            #~ raise exceptions.PermissionDenied("Unknown or inactive username %r. Please contact your system administrator." 
+            logger.info("Unknown or inactive username %r.",username)
+            raise exceptions.PermissionDenied()
               
         on_login(request,user)
     
@@ -713,4 +714,4 @@ class NoUserMiddleware(object):
         
         on_login(request,user)
         
-        
\ No newline at end of file
+        
